@@ -22,8 +22,9 @@ too (see ``make_decorator``)::
 
     rules_light.registry.setdefault('your_app.your_model.update', my_book)
 """
+from __future__ import unicode_literals
 
-from decorators import make_decorator
+from .decorators import make_decorator
 
 __all__ = ['is_staff', 'is_authenticated']
 
